@@ -1,4 +1,5 @@
 mod column_chunk;
+mod compression;
 mod file;
 mod page;
 mod row_group;
@@ -10,7 +11,9 @@ pub mod stream;
 mod stream_stream;
 
 mod dyn_iter;
-pub use dyn_iter::DynIter;
+pub use dyn_iter::{DynIter, DynStreamingIterator};
+
+pub use compression::{compress, Compressor};
 
 pub use file::write_file;
 
@@ -18,7 +21,7 @@ use crate::compression::Compression;
 use crate::page::CompressedPage;
 
 pub type RowGroupIter<'a, E> =
-    DynIter<'a, std::result::Result<DynIter<'a, std::result::Result<CompressedPage, E>>, E>>;
+    DynIter<'a, std::result::Result<DynStreamingIterator<'a, CompressedPage, E>, E>>;
 
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 pub struct WriteOptions {
